package com.gic.plug.web.controller;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.dto.ResourceDTO;
import com.gic.auth.dto.UserResourceDTO;
import com.gic.auth.service.ResourceApiService;
import com.gic.auth.service.UserResourceApiService;
import com.gic.plug.web.vo.StoreResourceVO;
import com.gic.store.dto.StoreWidgetDTO;
import com.gic.store.service.StoreWidgetApiService;
import org.apache.commons.lang.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.constants.Constants;
import com.gic.enterprise.utils.UserDetailUtils;
import com.gic.goods.api.util.Constant;
import com.gic.plug.web.strategy.init.StrategyInit;
import com.gic.search.business.api.constant.enums.OperateEnum;
import com.gic.widget.screening.api.dto.EsScreeningChainDetailDTO;
import com.gic.widget.screening.api.dto.EsScreeningEnterpriseCategorySceneInfoDTO;
import com.gic.widget.screening.api.dto.EsScreeningTemplateDTO;
import com.gic.widget.screening.api.service.EsScreeningInitService;
import com.gic.widget.screening.api.service.EsScreeningTemplateService;


/**
 *
 */
@Controller
public class ScreeningController {

    private Logger LOGGER = LogManager.getLogger(ScreeningController.class);

    @Autowired
    private EsScreeningInitService esScreeningInitService;
    @Autowired
    private EsScreeningTemplateService esScreeningTemplateService;
    @Autowired
    private StrategyInit strategyInit;
    @Autowired
    private StoreWidgetApiService storeWidgetApiService;
    @Autowired
    private UserResourceApiService userResourceApiService;
    @Autowired
    private ResourceApiService resourceApiService;

    /**
     * @return
     * @throws
     * @Title: getScreeningTemplate
     * @Description: 获取模板
     * @author xugh
     */
    @RequestMapping("get-screening-template")
    @ResponseBody
    public RestResponse getScreeningTemplate() {
        List<EsScreeningTemplateDTO> list = this.esScreeningTemplateService.queryEsScreeningTemplateList();
        return RestResponse.success(list);
    }

    /**
     * @param sceneCode
     * @return
     * @throws
     * @Title: getScreeningInitData
     * @Description: 获取初始化筛选条件
     * @author xugh
     */
    @RequestMapping("get-screening-init-data")
    @ResponseBody
    public RestResponse getScreeningInitData(@RequestParam(defaultValue = "member") String sceneCode) {
        String enterpriseId = UserDetailUtils.getUserDetail().getEnterpriseId().toString();
        if (Constants.STORE_SCENECODE.equals(sceneCode)) {
            enterpriseId = Constants.INDEX_ENTERPRISEID;
        }
        if (Constant.ERP_GOODS_SCREEN.equals(sceneCode) || Constant.WEIMOB_GOODS_SCREEN.equals(sceneCode)) {
            //TODO
            enterpriseId = "goods-test-1129";
        }
        List<EsScreeningEnterpriseCategorySceneInfoDTO> list = this.esScreeningInitService
                .queryEsScreeningByEnterpriseAndScene(enterpriseId, sceneCode);
        Collections.sort(list, new Comparator<EsScreeningEnterpriseCategorySceneInfoDTO>() {
            @Override
            public int compare(EsScreeningEnterpriseCategorySceneInfoDTO o1, EsScreeningEnterpriseCategorySceneInfoDTO o2) {
                return o1.getCreateTime().compareTo(o2.getCreateTime());
            }
        });
        List<EsScreeningChainDetailDTO> all = new ArrayList<>();
        for (EsScreeningEnterpriseCategorySceneInfoDTO dto : list) {
            String categoryId = dto.getSceneCategoryId();
            EsScreeningChainDetailDTO item = this.esScreeningInitService.findRootChainByCategoryId(categoryId);
            all.add(item);
        }
        return RestResponse.success(all);
    }

    @RequestMapping("get-screening-data")
    @ResponseBody
    public RestResponse getScreeningData(String widgetChainId) {
        List<EsScreeningChainDetailDTO> list = this.esScreeningInitService
                .queryEsScreeningByParentChainId(widgetChainId);
        return RestResponse.success(list);
    }

    @RequestMapping("get-screening-chain-detail")
    @ResponseBody
    public RestResponse getScreeningChainDetail(String parentChainId, String widgetFieldKey) {
        EsScreeningChainDetailDTO dto = this.esScreeningInitService.findChainDetail(parentChainId, widgetFieldKey);
        return RestResponse.success(dto);
    }


    @RequestMapping("get-screening-widget-chain-detail")
    @ResponseBody
    public Object getScreeningWidgetDetail(String widgetChainId) {
        EsScreeningChainDetailDTO dto = this.esScreeningInitService.findChainDetail(widgetChainId);
        return RestResponse.success(dto);
    }
}
